@@ -1,7 +1,7 @@
 import numpy as np
+import pytest
 from matplotlib import pyplot as plt
 
-import pytest
 from tikzplotlib import clean_figure, get_tikz_code
 
 RC_PARAMS = {"figure.figsize": [5, 5], "figure.dpi": 220, "pgf.rcfonts": False}
@@ -33,6 +33,45 @@ class Test_plottypes:
             assert numLinesRaw - numLinesClean == 18
         plt.close("all")
 
+    def test_logplot(self):
+        x = np.logspace(-3, 3, 20)
+        y = np.logspace(-3, 3, 20)
+
+        with plt.rc_context(rc=RC_PARAMS):
+            fig, ax = plt.subplots(1, 1, figsize=(5, 5))
+            ax.plot(x, y)
+            ax.set_xscale("log")
+            ax.set_yscale("log")
+            ax.set_ylim([10 ** (-2), 10 ** (2)])
+            ax.set_xlim([10 ** (-2), 10 ** (2)])
+            raw = get_tikz_code()
+
+            clean_figure(fig)
+            clean = get_tikz_code()
+            numLinesRaw = raw.count("\n")
+            numLinesClean = clean.count("\n")
+            assert numLinesRaw - numLinesClean == 11
+        plt.close("all")
+
+    def test_semilogplot(self):
+        x = np.logspace(-3, 3, 20)
+        y = np.linspace(1, 100, 20)
+
+        with plt.rc_context(rc=RC_PARAMS):
+            fig, ax = plt.subplots(1, 1, figsize=(5, 5))
+            ax.plot(x, y)
+            ax.set_xscale("log")
+            ax.set_xlim([10 ** (-2), 10 ** (2)])
+            ax.set_ylim([20, 80])
+            raw = get_tikz_code()
+
+            clean_figure(fig)
+            clean = get_tikz_code()
+            numLinesRaw = raw.count("\n")
+            numLinesClean = clean.count("\n")
+            assert numLinesRaw - numLinesClean == 6
+        plt.close("all")
+
     def test_step(self):
         x = np.linspace(1, 100, 20)
         y = np.linspace(1, 100, 20)
@@ -164,7 +203,7 @@ class Test_plottypes:
 
     def test_surface3D(self):
         from matplotlib import cm
-        from matplotlib.ticker import LinearLocator, FormatStrFormatter
+        from matplotlib.ticker import FormatStrFormatter, LinearLocator
 
         # Make data.
         X = np.arange(-5, 5, 0.25)
@@ -226,8 +265,8 @@ class Test_plottypes:
         plt.close("all")
 
     def test_contour3D(self):
-        from mpl_toolkits.mplot3d import axes3d
         from matplotlib import cm
+        from mpl_toolkits.mplot3d import axes3d
 
         with plt.rc_context(rc=RC_PARAMS):
             fig = plt.figure()
@@ -240,8 +279,8 @@ class Test_plottypes:
         plt.close("all")
 
     def test_polygon3D(self):
-        from matplotlib.collections import PolyCollection
         from matplotlib import colors as mcolors
+        from matplotlib.collections import PolyCollection
 
         with plt.rc_context(rc=RC_PARAMS):
             fig = plt.figure()
