@@ -229,8 +229,8 @@ def _cleanline(fighandle, axhandle, linehandle, target_resolution, scale_precisi
         visual_data = _get_visual_data(axhandle, data, is3D)
 
         if not is3D:
-            data = _move_points_closer(xLim, yLim, data)
-            visual_data = _get_visual_data(axhandle, data, is3D)
+            visual_data = _move_points_closer(xLim, yLim, visual_data)
+            visual_data = _get_visual_data(axhandle, visual_data, is3D)
 
         hasMarkers = not linehandle.get_marker() == "None"
         hasLines = not linehandle.get_linestyle() == "None"
@@ -276,8 +276,8 @@ def _clean_collections(
     visual_data = _get_visual_data(axhandle, data, is3D)
 
     if not is3D:
-        data = _move_points_closer(xLim, yLim, data)
-        visual_data = _get_visual_data(axhandle, data, is3D)
+        visual_data = _move_points_closer(xLim, yLim, visual_data)
+        visual_data = _get_visual_data(axhandle, visual_data, is3D)
 
     hasMarkers = True
     hasLines = False
@@ -325,17 +325,17 @@ def _get_visual_limits(fighandle, axhandle):
     xLim = np.array(axhandle.get_xlim())
     yLim = np.array(axhandle.get_ylim())
     if is3D:
-        zLim = np.array(axhandle.get_ylim())
+        zLim = np.array(axhandle.get_zlim())
 
     # Check for logarithmic scales
-    isXlog = axhandle.get_xscale() == "log"
+    isXlog = _axIsXLog(axhandle)
     if isXlog:
         xLim = np.log10(xLim)
-    isYLog = axhandle.get_yscale() == "log"
+    isYLog = _axIsYLog(axhandle)
     if isYLog:
         yLim = np.log10(yLim)
     if is3D:
-        isZLog = axhandle.get_zscale() == "log"
+        isZLog = _axIsZLog(axhandle)
         if isZLog:
             zLim = np.log10(zLim)
 
@@ -542,6 +542,18 @@ def _axIs3D(axhandle):
     return hasattr(axhandle, "get_zlim")
 
 
+def _axIsXLog(axhandle):
+    return axhandle.get_xscale() == "log"
+
+
+def _axIsYLog(axhandle):
+    return axhandle.get_yscale() == "log"
+
+
+def _axIsZLog(axhandle3D):
+    return axhandle3D.get_zscale() == "log"
+
+
 def _get_line_data(linehandle):
     """Retrieve 2D or 3D data from line object.
 
@@ -899,7 +911,7 @@ def _pixelate(x, y, xToPix, yToPix):
     )
     mask_sorted = np.concatenate([np.array([True]).reshape((-1,)), m], axis=0)
 
-    mask = np.ones((x.shape)) == 0
+    mask = np.ones(x.shape) == 0
     mask[id_orig] = mask_sorted
     mask[0] = True
     mask[-1] = True
